@@ -166,18 +166,7 @@ class EDFreader:
   EDFLIB_PHYSMIN_IS_PHYSMAX         = -25
   EDFLIB_DATARECORD_SIZE_TOO_BIG    = -26
 
-  EDFLIB_VERSION = 107
-
-# max size of annotationtext
-  __EDFLIB_WRITE_MAX_ANNOTATION_LEN = 40
-
-# bytes in datarecord for EDF annotations, must be an integer multiple of three and two
-  __EDFLIB_ANNOTATION_BYTES = 114
-
-# for writing only
-  __EDFLIB_MAX_ANNOTATION_CHANNELS = 64
-
-  __EDFLIB_ANNOT_MEMBLOCKSZ = 1000
+  EDFLIB_VERSION = 108
 
 # Annotation, onset and duration are expressed in units of 100 nano-Sec.
   EDFAnnotationStruct = namedtuple("annotation", ["onset", "duration", "description"])
@@ -760,8 +749,12 @@ class EDFreader:
     if buf.size < n:
       raise EDFexception("Buffer size is less than requested samples")
 
-    if (buf.dtype != np.int16) and (buf.dtype != np.int32) and (buf.dtype != np.float_) and (buf.dtype != np.float64):
-      raise EDFexception("Invalid buffer data type.")
+    if np.__version__ < "2.0.0":
+      if (buf.dtype != np.int16) and (buf.dtype != np.int32) and (buf.dtype != np.float_) and (buf.dtype != np.float64):
+        raise EDFexception("Invalid buffer data type.")
+    else:
+      if (buf.dtype != np.int16) and (buf.dtype != np.int32) and (buf.dtype != np.float64):
+        raise EDFexception("Invalid buffer data type.")
 
     if (buf.dtype == np.int16) and (self.__bdf != 0):
       raise EDFexception("Invalid buffer data type.")
