@@ -162,13 +162,17 @@ class EDFwriter:
   EDFLIB_PHYSMIN_IS_PHYSMAX         = -25
   EDFLIB_DATARECORD_SIZE_TOO_BIG    = -26
 
-  EDFLIB_VERSION = 107
+  EDFLIB_VERSION = 108
 
-# max size of annotationtext
+# max length of annotation's description in bytes
+# changing this value will break the unittest
   __EDFLIB_WRITE_MAX_ANNOTATION_LEN = 40
 
-# bytes in datarecord for EDF annotations, must be an integer multiple of three and two
-  __EDFLIB_ANNOTATION_BYTES = 114
+# number of bytes in datarecord for the annotations track, must be a multiple of six
+  if (((__EDFLIB_WRITE_MAX_ANNOTATION_LEN + 74) % 6) > 0):
+    __EDFLIB_ANNOTATION_BYTES = ((((__EDFLIB_WRITE_MAX_ANNOTATION_LEN + 74) // 6) + 1) * 6)
+  else:
+    __EDFLIB_ANNOTATION_BYTES = __EDFLIB_WRITE_MAX_ANNOTATION_LEN + 74
 
 # for writing only
   __EDFLIB_MAX_ANNOTATION_CHANNELS = 64
@@ -670,8 +674,12 @@ class EDFwriter:
     if buf.ndim != 1:
       return -1
 
-    if (buf.dtype != np.int16) and (buf.dtype != np.int32) and (buf.dtype != np.float_) and (buf.dtype != np.float64):
-      return -1
+    if np.__version__ < "2.0.0":
+      if (buf.dtype != np.int16) and (buf.dtype != np.int32) and (buf.dtype != np.float_) and (buf.dtype != np.float64):
+        return -1
+    else:
+      if (buf.dtype != np.int16) and (buf.dtype != np.int32) and (buf.dtype != np.float64):
+        return -1
 
     if (buf.dtype == np.int16) and (self.__bdf != 0):
       return -1
